@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_SUCCESS: '84' >>>
+# <<< EXECUTE_SUCCESS: '84' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -16,8 +16,8 @@ our $VERSION = 0.000_020;
 use RPerl::Algorithm::Math::GeometricAlgebra;
 
 # [[[ OPERATIONS ]]]
-my number__array_ref $input_vector_1 = [ -999_999, 2.0, 4.0, 6.0 ];
-my number__array_ref $input_vector_2 = [ -999_999, 3.0, 6.0, 9.0 ];
+my number_arrayref $input_vector_1 = [ -999_999, 2.0, 4.0, 6.0 ];
+my number_arrayref $input_vector_2 = [ -999_999, 3.0, 6.0, 9.0 ];
 my number $retval_number
     = inner_product__vector_vector_euclidean( $input_vector_1,
     $input_vector_2 );
