@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
-# <<< COMPILE_ERROR: 'Unexpected token:  ##' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  ##' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Critic::Class_00_Bad_03;
@@ -17,11 +17,12 @@ use RPerl::Test;
 ## o critic qw(ProhibitUselessNoCritic ProhibitMagicNumbers RequireCheckedSyscalls)  # USER DEFAULT 1: allow numeric values & print operator
 
 # [[[ OO PROPERTIES ]]]
-our %properties = ( ## no critic qw(ProhibitPackageVars)  # USER DEFAULT 3: allow OO properties
-    empty_property => my integer $TYPED_empty_property = 2
-);
+our hashref $properties
+    = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS ]]]
-our void__method $empty_method = sub { return 2; };
+# [[[ OO METHODS & SUBROUTINES ]]]
+our void_method $empty_method = sub {
+    return 2;
+};
 
 1;                  # end of class
