@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPC02' >>>
-# <<< COMPILE_ERROR: 'Perl::Critic::Policy::Modules::RequireVersionVar' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPC02' >>>
+# <<< PARSE_ERROR: 'Perl::Critic::Policy::Modules::RequireVersionVar' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::Header::Package_00_Bad_03;
@@ -10,6 +10,8 @@ use RPerl
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 2; };
+our void $empty_sub = sub {
+    return 2;
+};
 
 1;                  # end of package
