@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::LiteralNumber::Package_00_Bad_03;
@@ -9,6 +9,6 @@ use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return 2.; };
+our integer $empty_sub = sub { return 2.; };
 
 1;                  # end of package
