@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::LiteralString::Package_DoubleQuotes_15_Bad_01;
@@ -10,6 +10,8 @@ our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
 # DEV NOTE: the rules for sigils inside double quotes are too complicated for now
-our void $empty_sub = sub { return "@ \@bar \$foo $ \n"; };
+our string $empty_sub = sub {
+    return "@ \@bar \$foo $ \n";
+};
 
-1;                  # end of package
+1;    # end of package
