@@ -6,6 +6,8 @@ use RPerl;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
-our void $empty_sub = sub { return '`~!#%^&*()-_=+[]{}\|;:",<.>/?'; };
+our string $empty_sub = sub {
+    return '`~!#%^&*()-_=+[]{}\|;:",<.>/?';
+};
 
-1;                  # end of package
+1;    # end of package
