@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
-# <<< COMPILE_ERROR: 'Unexpected token:  ->' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'Unexpected Token:  >' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -30,7 +30,7 @@ print 'have $bat = ', $bat, "\n";
 print 'have $baz = ', $baz, "\n";
 print 'have $bax = ', $bax, "\n";
 
-my integer__array_ref $quux = [ 5, 6, 7, 8 ];
+my integer_arrayref $quux = [ 5, 6, 7, 8 ];
 $foo = scalar @{$quux};
 $bar = scalar @{ [] };
 $bat = scalar @{ [0] };
