@@ -1,6 +1,6 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPAPL02' >>>
-# <<< COMPILE_ERROR: 'near "my number__hash_ref foo "' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPAPL02' >>>
+# <<< PARSE_ERROR: 'near "my number_hashref foo "' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::SubroutineArguments::Package_03_Bad;
@@ -11,7 +11,7 @@ our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
 our void $empty_sub = sub {
-    ( my number__hash_ref foo ) = @_;
+    ( my number_hashref foo ) = @_;
     return 1;
 };
 
