@@ -1,8 +1,8 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_ERROR: 'ERROR ENV01, TYPE-CHECKING MISMATCH' >>>
-# <<< RUN_ERROR: 'number value expected but non-number value found' >>>
+# <<< EXECUTE_ERROR: 'ERROR ENV01, TYPE-CHECKING MISMATCH' >>>
+# <<< EXECUTE_ERROR: 'number value expected but non-number value found' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -17,4 +17,4 @@ our $VERSION = 0.000_001;
 use RPerl::Test::TypeCheckingOn::AllTypes;
 
 # [[[ OPERATIONS ]]]
-check__number('abcd');
+check_number('abcd');
