@@ -1,9 +1,9 @@
 #!/usr/bin/perl
 
 # [[[ PREPROCESSOR ]]]
-# <<< RUN_ERROR: 'ERROR ENVHVRV03, TYPE-CHECKING MISMATCH' >>>
-# <<< RUN_ERROR: "number__hash_ref element value expected but non-number value found at key 'd'" >>>
-# <<< RUN_ERROR: 'in variable $input_1 from subroutine check__number__hash_ref()' >>>
+# <<< EXECUTE_ERROR: 'ERROR ENVHVRV03, TYPE-CHECKING MISMATCH' >>>
+# <<< EXECUTE_ERROR: "number_hashref element value expected but non-number value found at key 'd'" >>>
+# <<< EXECUTE_ERROR: 'in variable $input_1 from subroutine check_number_hashref()' >>>
 
 # [[[ HEADER ]]]
 use strict;
@@ -18,4 +18,4 @@ our $VERSION = 0.000_001;
 use RPerl::Test::TypeCheckingTrace::AllTypes;
 
 # [[[ OPERATIONS ]]]
-check__number__hash_ref( { a => -999_999, b => 3, c => 4, d => [ 0, 1, 2 ] } );
+check_number_hashref( { a => -999_999, b => 3, c => 4, d => [ 0, 1, 2 ] } );
