@@ -1,5 +1,5 @@
 # [[[ PREPROCESSOR ]]]
-# <<< COMPILE_ERROR: 'ERROR ECVPARP00' >>>
+# <<< PARSE_ERROR: 'ERROR ECVPARP00' >>>
 
 # [[[ HEADER ]]]
 package RPerl::Test::VersionNumber::Class_00_Bad_05;
@@ -13,11 +13,12 @@ use parent qw(RPerl::Test);
 use RPerl::Test;
 
 # [[[ OO PROPERTIES ]]]
-our %properties = ( ## no critic qw(ProhibitPackageVars)  # USER DEFAULT 3: allow OO properties
-    empty_property => my integer $TYPED_empty_property = 2
-);
+our hashref $properties
+    = { empty_property => my integer $TYPED_empty_property = 2 };
 
-# [[[ OO METHODS ]]]
-our void__method $empty_method = sub { return 2; };
+# [[[ OO METHODS & SUBROUTINES ]]]
+our void_method $empty_method = sub {
+    return 2;
+};
 
 1;                  # end of class
